[![CI](https://github.com/DiamondLightSource/fastcs-catio/actions/workflows/ci.yml/badge.svg)](https://github.com/DiamondLightSource/fastcs-catio/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/DiamondLightSource/fastcs-catio/branch/main/graph/badge.svg)](https://codecov.io/gh/DiamondLightSource/fastcs-catio)
[![PyPI](https://img.shields.io/pypi/v/fastcs-catio.svg)](https://pypi.org/project/fastcs-catio)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0)

# fastcs_catio

Control system integration of EtherCAT I/O devices running under TwinCAT using pyads and FastCS

This is where you should write a short paragraph that describes what your module does,
how it does it, and why people should use it.

Source          | <https://github.com/DiamondLightSource/fastcs-catio>
:---:           | :---:
PyPI            | `pip install fastcs-catio`
Docker          | `docker run ghcr.io/diamondlightsource/fastcs-catio:latest`
Documentation   | <https://diamondlightsource.github.io/fastcs-catio>
Releases        | <https://github.com/DiamondLightSource/fastcs-catio/releases>

This is where you should put some images or code snippets that illustrate
some relevant examples. If it is a library then you might put some
introductory code here:

```python
from fastcs_catio import __version__

print(f"Hello fastcs_catio {__version__}")
```

Or if it is a commandline tool then you might put some example commands here:

```
python -m fastcs_catio --version
```

<!-- README only content. Anything below this line won't be included in index.md -->

See https://diamondlightsource.github.io/fastcs-catio for more detailed documentation.
